<?php
/**
 * @file
 * Plugin to handle the 'snapengage_widget' content type.
 */

/**
 * Plugins are described by creating a $plugin array which will be used
 * by the system that includes this file.
 */
$plugin = array(
  'title' => t('SnapEngage Widget'),
  'single' => TRUE,
  'description' => t('Add a SnapEngage widget.'),
  'category' => t('Widgets'),
  'defaults' => array(
    'snapengage_widget_id' => NULL,
    'snapengage_widget_position' => variable_get('snapengage_widget_position', 0),
    'snapengage_widget_position_offset' => variable_get('snapengage_widget_position_offset', 35),
    'snapengage_widget_button_style' => variable_get('snapengage_widget_button_style', 'default'),
  ),
);

/**
 * Output function.
 */
function snapengage_snapengage_widget_content_type_render($subtype, $conf, $panel_args) {
  $block = new stdClass();

  // Add widget code if there's a widget id.
  if (!empty($conf['snapengage_widget_id'])) {
    _snapengage_add_script(
      $conf['snapengage_widget_id'],
      $conf['snapengage_widget_position'],
      $conf['snapengage_widget_position_offset'],
      $conf['snapengage_widget_button_style']
    );
  }
  return $block;
}

/**
 * Define the settings form.
 */
function snapengage_snapengage_widget_content_type_edit_form($form, &$form_state) {
  $conf = $form_state['conf'];

  $form['snapengage_widget_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Widget ID'),
    '#default_value' => $conf['snapengage_widget_id'],
    '#required' => TRUE,
    '#description' => t('Your widget ID. It will look somewhat like this: "abcdefgh-1234-ijkl-5678-mnopqrstuvwx". You can find it at <a href="!url">!url</a>.', array('!url' => 'https://secure.snapengage.com/widget')),
  );
  $form['snapengage_widget_position'] = array(
    '#type' => 'select',
    '#title' => t('Widget Dock Position'),
    '#default_value' => $conf['snapengage_widget_position'],
    '#required' => TRUE,
    '#options' => array(
      0 => t('Left'),
      1 => t('Right'),
      2 => t('Top'),
      3 => t('Bottom'),
    ),
    '#description' => t('Please select the docking placement of the SnapEngage button.'),
  );
  $form['snapengage_widget_position_offset'] = array(
    '#type' => 'textfield',
    '#title' => t('Widget Offset'),
    '#default_value' => $conf['snapengage_widget_position_offset'],
    '#field_suffix' => '%',
    '#size' => 3,
    '#required' => TRUE,
    '#description' => t('Please enter an the offset in percentage for the button.'),
  );
  if (module_exists('html5_tools')) {
    $form['snapengage_widget_position_offset']['#type'] = 'numberfield';
    $form['snapengage_widget_position_offset']['#min'] = 0;
    $form['snapengage_widget_position_offset']['#max'] = 100;
  }
  $form['snapengage_widget_button_style'] = array(
    '#type' => 'select',
    '#title' => t('Button Style'),
    '#default_value' => $conf['snapengage_widget_button_style'],
    '#required' => TRUE,
    '#options' => array(
      'default' => t('Default'),
      // Image is not supported - it requires a Pro account.
      // 'image' => t('Your own image'),
      'dynamic' => t('Dynamic live chat button'),
      'nobutton' => t('No button'),
    ),
    '#description' => t('Select a button type.'),
  );

  unset($form['override_title'], $form['override_title_text'], $form['override_title_markup']);
  return $form;
}

/**
 * Store the new configuration settings.
 */
function snapengage_snapengage_widget_content_type_edit_form_submit($form, &$form_state) {
  $elements = array(
    'snapengage_widget_id',
    'snapengage_widget_position',
    'snapengage_widget_position_offset',
    'snapengage_widget_button_style',
  );
  foreach ($elements as $element) {
    if (isset($form_state['values'][$element])) {
      $form_state['conf'][$element] = $form_state['values'][$element];
    }
  }
}
